Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3341)

Unified Diff: chrome/browser/chrome_browser_main_win.cc

Issue 2710713004: Revert "Use the Windows MDM API to check if the machine is being managed." (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chrome_browser_main_win.cc
diff --git a/chrome/browser/chrome_browser_main_win.cc b/chrome/browser/chrome_browser_main_win.cc
index bf521435e96daaaa45003ec3b9b51d319002ce03..99a0922b770a7860954421bb084b70c92d98bde2 100644
--- a/chrome/browser/chrome_browser_main_win.cc
+++ b/chrome/browser/chrome_browser_main_win.cc
@@ -312,11 +312,10 @@ void ChromeBrowserMainPartsWin::PreMainMessageLoopStart() {
}
int ChromeBrowserMainPartsWin::PreCreateThreads() {
- // Record whether the machine is enterprise managed in a crash key. This will
- // be used to better identify whether crashes are from enterprise users.
- base::debug::SetCrashKeyValue(
- crash_keys::kIsEnterpriseManaged,
- base::win::IsEnterpriseManaged() ? "yes" : "no");
+// Record whether the machine is domain joined in a crash key. This will be used
+// to better identify whether crashes are from enterprise users.
+ base::debug::SetCrashKeyValue(crash_keys::kEnrolledToDomain,
+ base::win::IsEnrolledToDomain() ? "yes" : "no");
int rv = ChromeBrowserMainParts::PreCreateThreads();
« no previous file with comments | « chrome/browser/chrome_browser_main.cc ('k') | chrome/browser/component_updater/chrome_component_updater_configurator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698